## $Id: test_vocabularies.py 7616 2012-02-09 08:02:40Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
import unittest
from waeup.sirp.students.vocabularies import StudyLevelSource
from waeup.sirp.university.certificate import Certificate


class FakeStudyCourse(object):

    def __init__(self):
        cert = Certificate(code="CERT1")
        cert.start_level = 100
        cert.end_level = 500
        self.certificate = cert

class VocabularyTests(unittest.TestCase):

    def test_studylevelsource(self):
        studycourse = FakeStudyCourse()
        studylevelsource = StudyLevelSource().factory
        values = studylevelsource.getValues(studycourse)
        self.assertEqual(values, [100, 110, 120, 200, 210, 220, 300, 310, 320,
            400, 410, 420, 500, 510, 520, 600, 610])
        self.assertTrue(studylevelsource.getTitle(studycourse, 0),
            'Error: level id 0 out of range')
        self.assertTrue(studylevelsource.getTitle(studycourse, 10),
            'Error: level id 10 out of range')
        self.assertTrue(studylevelsource.getTitle(studycourse, 100),
            '100 (Year 1)')
        self.assertTrue(studylevelsource.getTitle(studycourse, 110),
            '100 (Year 1) on 1. probation')
        self.assertTrue(studylevelsource.getTitle(studycourse, 120),
            '100 (Year 1) on 2. probation')
        self.assertTrue(studylevelsource.getTitle(studycourse, 500),
            '500 (Year 5)')
        self.assertTrue(studylevelsource.getTitle(studycourse, 600),
            '500 (Year 5) spillover')
        self.assertTrue(studylevelsource.getTitle(studycourse, 610),
            '500 (Year 5) 2nd spillover')
        self.assertTrue(studylevelsource.getTitle(studycourse, 620),
            'Error: level id 620 out of range')
        self.assertTrue(studylevelsource.getTitle(studycourse, 900),
            'Error: level id 900 out of range')
        # Now we change the certificates start_level in order to include
        # pre-studies
        studycourse.certificate.start_level = 10
        self.assertTrue(studylevelsource.getTitle(studycourse, 10),
            'Pre-Studies')
